{ config, lib, pkgs, ... }:

let
  inherit (lib) mkIf;

  cfg = config.pepe.core.graphics;
in
{
  options.pepe.core.graphics = with lib; {
    enable = mkEnableOption "Enable graphics";
    nvidia = mkEnableOption "Enable nvidia graphics";
  };

  config = mkIf cfg.enable {
    hardware = {
      graphics = {
        enable = true;
        extraPackages = with pkgs; mkIf cfg.nvidia [ vaapiVdpau ];
      };

      nvidia = mkIf cfg.nvidia {
        modesetting.enable = true;
        powerManagement.enable = false;
        powerManagement.finegrained = false;
        open = false;
        nvidiaSettings = true;
        package = config.boot.kernelPackages.nvidiaPackages.latest;
      };
    };

    services = {
      xserver = {
        enable = true;
        videoDrivers = mkIf cfg.nvidia [ "nvidia" ];
      };
    };
  };
}

